<?php
namespace AvanteElementor\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * Elementor Blog Posts
 *
 * Elementor widget for blog posts
 *
 * @since 1.0.0
 */
class Avante_Contact_Form extends Widget_Base {

	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'avante-contact-form';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Contact Form 7', 'avante-elementor' );
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-form-horizontal';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'avante-theme-widgets-category' ];
	}

	/**
	 * Retrieve the list of scripts the widget depended on.
	 *
	 * Used to set scripts dependencies required to run the widget.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget scripts dependencies.
	 */
	public function get_script_depends() {
		return [ 'avante-elementor' ];
	}

	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
			'section_content',
			[
				'label' => __( 'Content', 'avante-elementor' ),
			]
		);

		$this->add_control(
			'form_id',
			[
				'label' => __( 'Contact Form', 'avante-elementor' ),
				'type' => Controls_Manager::SELECT2,
				'options' => avante_get_contact_forms(),
				'multiple' => false,
			]
		);
		
		$this->end_controls_section();
		
		$this->start_controls_section(
			'section_label_style',
			array(
				'label'      => esc_html__( 'Label', 'avante-elementor' ),
				'tab'        => Controls_Manager::TAB_STYLE,
				'show_label' => false,
			)
		);
		
		$this->add_control(
			'label_font_color',
			[
				'label' => __( 'Label Font Color', 'avante-elementor' ),
				'type' => Controls_Manager::COLOR,
				'default' => '#000000',
				'selectors' => [
					'{{WRAPPER}} .avante-contact-form-content-wrapper label' => 'color: {{VALUE}}',
				],
			]
		);
		
		$this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			[
				'name' => 'label_typography',
				'label' => __( 'Label Typography', 'avante-elementor' ),
				'selector' => '{{WRAPPER}} .avante-contact-form-content-wrapper label',
			]
		);
		
		$this->end_controls_section();
		
		$this->start_controls_section(
			'section_field_style',
			array(
				'label'      => esc_html__( 'Fields', 'avante-elementor' ),
				'tab'        => Controls_Manager::TAB_STYLE,
				'show_label' => false,
			)
		);
		
		$this->add_control(
			'field_background',
			[
				'label' => __( 'Fields Background', 'avante-elementor' ),
				'type' => Controls_Manager::COLOR,
				'default' => '#f9f9f9',
				'selectors' => [
					'{{WRAPPER}} .avante-contact-form-content-wrapper input, {{WRAPPER}} .avante-contact-form-content-wrapper textarea, {{WRAPPER}} .avante-contact-form-content-wrapper select' => 'background-color: {{VALUE}}',
				],
			]
		);
		
		$this->add_control(
			'field_font_color',
			[
				'label' => __( 'Fields Font Color', 'avante-elementor' ),
				'type' => Controls_Manager::COLOR,
				'default' => '#000000',
				'selectors' => [
					'{{WRAPPER}} .avante-contact-form-content-wrapper input, {{WRAPPER}} .avante-contact-form-content-wrapper textarea, {{WRAPPER}} .avante-contact-form-content-wrapper select' => 'color: {{VALUE}}',
					
					'{{WRAPPER}} .avante-contact-form-content-wrapper .avante-select::after' => 'background-color: {{VALUE}}',
				],
			]
		);
		
		$this->add_control(
			'field_border_color',
			[
				'label' => __( 'Fields Border Color', 'avante-elementor' ),
				'type' => Controls_Manager::COLOR,
				'default' => '#f9f9f9',
				'selectors' => [
					'{{WRAPPER}} .avante-contact-form-content-wrapper input, {{WRAPPER}} .avante-contact-form-content-wrapper textarea, {{WRAPPER}} .avante-contact-form-content-wrapper select' => 'border-color: {{VALUE}}',
				],
			]
		);
		
		$this->add_control(
			'field_focus_color',
			[
				'label' => __( 'Fields Focus Color', 'avante-elementor' ),
				'type' => Controls_Manager::COLOR,
				'default' => '#1C58F6',
				'selectors' => [
					'{{WRAPPER}} .avante-contact-form-content-wrapper input:focus, {{WRAPPER}} .avante-contact-form-content-wrapper textarea:focus, {{WRAPPER}} .avante-contact-form-content-wrapper select:focus' => 'border-color: {{VALUE}}',
				],
			]
		);
		
		$this->add_control(
			'field_border_radius',
			[
				'label' => __( 'Fields Border Radius', 'avante-elementor' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 25,
						'step' => 1,
					],
				],
				'default' => [
					'unit' => 'px',
					'size' => 5,
				],
				'selectors' => [
					'{{WRAPPER}} .avante-contact-form-content-wrapper input, {{WRAPPER}} .avante-contact-form-content-wrapper textarea, {{WRAPPER}} .avante-contact-form-content-wrapper select' => 'border-radius: {{SIZE}}{{UNIT}};',
				],
			]
		);
		
		$this->add_responsive_control(
			'field_margin',
			[
				'label' => __( 'Field Margin', 'avante-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px' ],
				'selectors' => [
					'{{WRAPPER}} .avante-contact-form-content-wrapper .wpcf7-form > p' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		
		$this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			[
				'name' => 'field_typography',
				'label' => __( 'Input Typography', 'avante-elementor' ),
				'selector' => '{{WRAPPER}} .avante-contact-form-content-wrapper input, {{WRAPPER}} .avante-contact-form-content-wrapper textarea, {{WRAPPER}} .avante-contact-form-content-wrapper select',
			]
		);
		
		$this->end_controls_section();
		
		$this->start_controls_section(
			'section_button_style',
			array(
				'label'      => esc_html__( 'Button', 'avante-elementor' ),
				'tab'        => Controls_Manager::TAB_STYLE,
				'show_label' => false,
			)
		);
		
		$this->add_control(
			'button_background',
			[
				'label' => __( 'Button Background', 'avante-elementor' ),
				'type' => Controls_Manager::COLOR,
				'default' => '#000000',
				'selectors' => [
					'{{WRAPPER}} .avante-contact-form-content-wrapper input[type=submit]' => 'background: {{VALUE}}',
				],
			]
		);
		
		$this->add_control(
			'button_font_color',
			[
				'label' => __( 'Button Font Color', 'avante-elementor' ),
				'type' => Controls_Manager::COLOR,
				'default' => '#ffffff',
				'selectors' => [
					'{{WRAPPER}} .avante-contact-form-content-wrapper input[type=submit]' => 'color: {{VALUE}}',
				],
			]
		);
		
		$this->add_control(
			'button_border_color',
			[
				'label' => __( 'Button Border Color', 'avante-elementor' ),
				'type' => Controls_Manager::COLOR,
				'default' => '#000000',
				'selectors' => [
					'{{WRAPPER}} .avante-contact-form-content-wrapper input[type=submit]' => 'border-color: {{VALUE}}',
				],
			]
		);
		
		$this->add_control(
			'button_hover_background',
			[
				'label' => __( 'Button Hover Background', 'avante-elementor' ),
				'type' => Controls_Manager::COLOR,
				'default' => '#000000',
				'selectors' => [
					'{{WRAPPER}} .avante-contact-form-content-wrapper input[type=submit]:hover' => 'background: {{VALUE}}',
				],
			]
		);
		
		$this->add_control(
			'button_hover_font_color',
			[
				'label' => __( 'Button Hover Font Color', 'avante-elementor' ),
				'type' => Controls_Manager::COLOR,
				'default' => '#ffffff',
				'selectors' => [
					'{{WRAPPER}} .avante-contact-form-content-wrapper input[type=submit]:hover' => 'color: {{VALUE}}',
				],
			]
		);
		
		$this->add_control(
			'button_hover_border_color',
			[
				'label' => __( 'Button Hover Border Color', 'avante-elementor' ),
				'type' => Controls_Manager::COLOR,
				'default' => '#000000',
				'selectors' => [
					'{{WRAPPER}} .avante-contact-form-content-wrapper input[type=submit]:hover' => 'border-color: {{VALUE}}',
				],
			]
		);
		
		$this->add_control(
			'button_border_radius',
			[
				'label' => __( 'Button Border Radius', 'avante-elementor' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 25,
						'step' => 1,
					],
				],
				'default' => [
					'unit' => 'px',
					'size' => 5,
				],
				'selectors' => [
					'{{WRAPPER}} .avante-contact-form-content-wrapper input[type=submit]' => 'border-radius: {{SIZE}}{{UNIT}};',
				],
			]
		);
		
		$this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			[
				'name' => 'button_typography',
				'label' => __( 'Button Typography', 'avante-elementor' ),
				'selector' => '{{WRAPPER}} .avante-contact-form-content-wrapper input[type=submit]',
			]
		);
		
		$this->end_controls_section();
	}

	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function render() {
		include(AVANTE_ELEMENTOR_PATH.'templates/contact-form/index.php');
	}

	/**
	 * Render the widget output in the editor.
	 *
	 * Written as a Backbone JavaScript template and used to generate the live preview.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function content_template() {
		return '';
	}
}
