<?php

namespace MotoPress\Appointment\CheckoutFields;

use MotoPress\Appointment\CheckoutFields\Emailtags\BookingCheckoutFieldsTags;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Adds some functionality to Appointment Booking plugin's emails.
 */
class EmailsHandler {

	public function __construct() {

		add_filter( 'mpa_admin_new_booking_email_tags', array( $this, 'add_cf_tags' ), 10, 1 );
		add_filter( 'mpa_admin_pending_booking_email_tags', array( $this, 'add_cf_tags' ), 10, 1 );
		add_filter( 'mpa_customer_new_booking_email_tags', array( $this, 'add_cf_tags' ), 10, 1 );
		add_filter( 'mpa_customer_cancelled_booking_email_tags', array( $this, 'add_cf_tags' ), 10, 1 );
		add_filter( 'mpa_customer_pending_booking_email_tags', array( $this, 'add_cf_tags' ), 10, 1 );
		add_filter( 'mpa_customer_approved_booking_email_tags', array( $this, 'add_cf_tags' ), 10, 1 );
		add_filter( 'mpa_admin_approved_booking_email_tags', array( $this, 'add_cf_tags' ), 10, 1 );
		add_filter( 'mpa_customer_approved_payment_email_tags', array( $this, 'add_cf_tags' ), 10, 1 );
		add_filter( 'mpa_customer_cancelled_booking_email_tags', array( $this, 'add_cf_tags' ), 10, 1 );

	}

	/**
	 * Add checkout fields tags
	 *
	 * @param [type] $tags
	 * @return void
	 */
	public function add_cf_tags( $tags ) {

		$customerTags = $tags->getTags();
		$cf_emailtags = $this->addCheckoutFieldsEmailsTags();

		foreach ( $cf_emailtags as $value ) {
			$name        = $value['name'];
			$description = $value['description'];
			$type        = $value['type'];

			// add checkout fields tags to Customer tags group
			$customerTags['customer']->add( new BookingCheckoutFieldsTags( $name, $description, $type ) );
		}

		return $tags;
	}

	/**
	 * Get checkout fields tags
	 *
	 * @return array
	 */
	public function addCheckoutFieldsEmailsTags(): array {

		$customFields       = mpa_checkout_fields_get_custom_customer_fields();
		$CheckoutFieldsTags = array();

		if ( ! empty( $customFields ) ) {
			$CheckoutFieldsTags = array_map(
				function ( $fieldArgs, $fieldName ) {
					return array(
						'name'        => $fieldName,
						// Translators: %s is an email tag name. For example: "Customer Birth Date".
						'description' => sprintf( esc_html__( 'Customer %s', 'mpa-checkout-fields' ), $fieldArgs['label'] ),
						'type'        => $fieldArgs['type'],
					);
				},
				$customFields,
				array_keys( $customFields )
			);
		}

		return $CheckoutFieldsTags;
	}
}
