<?php

namespace MotoPress\Appointment\CheckoutFields;

use MotoPress\Appointment\CheckoutFields\Admin\EditCheckoutFieldPage;
use MotoPress\Appointment\CheckoutFields\Admin\PluginLicenseSettingsField;

/**
 * @since 1.0
 */
class Plugin {

	/** @var static */
	protected static $instance = null;

	/** @var \MotoPress\Appointment\CheckoutFields\Admin\EddLicenseApi */
	private $eddLicenseApi = null;

	/** @var \MotoPress\Appointment\CheckoutFields\PostTypes\CheckoutFieldPostType */
	private $checkoutFieldsPostType = null;

	/** @var \MotoPress\Appointment\CheckoutFields\Repositories\CheckoutFieldRepository */
	private $checkoutFieldRepository = null;

	/** @var MotoPress\Appointment\CheckoutFields\Admin\PluginLifecycleHandler */
	private $pluginLifecycleHandler = null;

	/** @var \MotoPress\Appointment\CheckoutFields\Settings */
	protected $settings = null;

	// prevent cloning of singleton
	public function __clone() {}
	public function __wakeup() {}


	public static function getInstance(): Plugin {

		if ( is_null( static::$instance ) ) {
			static::$instance = new static();
		}

		return static::$instance;
	}


	private function __construct() {

		$this->settings      = new Settings();
		$this->eddLicenseApi = new Admin\EddLicenseApi();

		$this->loadCustomPostType();

		load_plugin_textdomain(
			'mpa-checkout-fields',
			false,
			plugin_basename( PLUGIN_DIR ) . 'languages/'
		);

		$this->pluginLifecycleHandler = new Admin\PluginLifecycleHandler( PLUGIN_FILE );

		add_action(
			'plugins_loaded',
			function () {
				$this->loadPlugin();
			}
		);

	}

	private function loadCustomPostType() {
		if ( null == $this->checkoutFieldsPostType && class_exists( 'MotoPress\Appointment\PostTypes\AbstractPostType' ) ) {
			$this->checkoutFieldsPostType = new PostTypes\CheckoutFieldPostType();
			$this->checkoutFieldsPostType->createManagePage();
			new EditCheckoutFieldPage( $this->checkoutFieldsPostType->getPostType() );
			$this->checkoutFieldRepository = new Repositories\CheckoutFieldRepository( $this->checkoutFieldsPostType->getPostType() );
		}
	}


	private function loadPlugin() {

		if ( ! $this->pluginLifecycleHandler->isWPEnvironmentSuitedForPlugin() ) {
			return;
		}

		// Register plugin custom settings field
		add_filter(
			'mpa_' . PluginLicenseSettingsField::TYPE . '_field_class',
			function () {
				return PluginLicenseSettingsField::class;
			}
		);

		PluginLicenseSettingsField::registerField();

		require_once PLUGIN_DIR . 'includes/polyfills.php';

		new CheckoutFieldsHandler();
		new EmailsHandler();

		if ( wp_doing_ajax() ) {

			new Listeners\Ajax();

		} elseif ( ! wp_doing_cron() ) {

			new Views\ViewActions();

		}

		// Checkout field metabox for booking
		new Metaboxes\CheckoutFieldsBookingMetabox( 'mpa_booking' );
		// Checkout field metabox
		new Metaboxes\CheckoutFieldMetabox( $this->checkoutFieldsPostType->getPostType() );
	}

	public function settings(): Settings {
		return $this->settings;
	}

	public function getEddLicenseApi(): Admin\EddLicenseApi {
		return $this->eddLicenseApi;
	}

	public function getCheckoutFieldRepository(): Repositories\CheckoutFieldRepository {
		return $this->checkoutFieldRepository;
	}

	public function getCheckoutFieldsPostType(): PostTypes\CheckoutFieldPostType {
		return $this->checkoutFieldsPostType;
	}

	public function capabilities(): UsersAndRoles\Capabilities {
		return new UsersAndRoles\Capabilities();
	}

	public static function getPluginAuthorName(): string {
		return AUTHOR;
	}

	public static function getPluginVersion(): string {
		return VERSION;
	}

	public static function getPluginSourceServerUrl(): string {
		return STORE_URI;
	}

	public function isEDDLicenseEnabled(): bool {
		return (bool) apply_filters( 'mpa_checkout_fields_use_edd_license', true );
	}
}
