<?php

namespace MotoPress\Appointment\CheckoutFields\Bundles;

/**
 * @since 1.0.0
 */
class CustomerBundle {

	const CUSTOMER_FIELD_NAME_NAME  = 'name';
	const CUSTOMER_FIELD_NAME_EMAIL = 'email';
	const CUSTOMER_FIELD_NAME_PHONE = 'phone';
	const CUSTOMER_FIELD_NAME_NOTE  = 'notes';

	protected $allFields     = null;
	protected $defaultFields = array();

	public function __construct() {
		$this->initDefaults();
	}

	/**
	 * @param string $fieldName
	 * @return bool
	 */
	public function isDefaultField( $fieldName ) {
		return array_key_exists( $fieldName, $this->defaultFields );
	}

	/**
	 * @return array
	 */
	public function getDefaultFields() {
		return $this->defaultFields;
	}

	/**
	 * @return array
	 */
	public function getCustomerFields() {
		if ( is_null( $this->allFields ) ) {
			$this->allFields = apply_filters( 'mpa_cf_customer_fields', $this->defaultFields );
		}

		return $this->allFields;
	}

	/**
	 * @return array
	 */
	public function getCustomFields() {
		$customerFields = $this->getCustomerFields();
		$customFields   = array_diff_key( $customerFields, $this->defaultFields );

		return $customFields;
	}

	protected function initDefaults() {

		$this->defaultFields = array(
			static::CUSTOMER_FIELD_NAME_NAME  => array(
				'label'    => __( 'Name', 'mpa-checkout-fields' ),
				'type'     => 'text',
				'enabled'  => true,
				'required' => true,
			),
			static::CUSTOMER_FIELD_NAME_EMAIL => array(
				'label'    => __( 'Email', 'mpa-checkout-fields' ),
				'type'     => 'email',
				'enabled'  => true,
				'required' => true,
			),
			static::CUSTOMER_FIELD_NAME_PHONE => array(
				'label'    => __( 'Phone', 'mpa-checkout-fields' ),
				'type'     => 'phone',
				'enabled'  => true,
				'required' => true,
			),
			static::CUSTOMER_FIELD_NAME_NOTE  => array(
				'label'    => __( 'Notes', 'mpa-checkout-fields' ),
				'type'     => 'textarea',
				'enabled'  => true,
				'required' => false,
			),
		);
	}
}
