<?php

namespace MotoPress\Appointment\CheckoutFields\EmailTags;

use MotoPress\Appointment\CheckoutFields\Fields\FileUploadField;
use MotoPress\Appointment\Emails\Tags\Booking\AbstractBookingEntityTag;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * @since 1.0.0
 */
class BookingCheckoutFieldsTags extends AbstractBookingEntityTag {

	protected $name        = '';
	protected $description = '';
	protected $type        = '';

	public function __construct( string $name, string $description, string $type ) {
		$this->name        = $name;
		$this->description = $description;
		$this->type        = $type;
	}

	public function getName(): string {
		return 'customer_' . $this->name;
	}

	public function description(): string {
		return $this->description;
	}

	public function getTagContent(): string {

		$id = $this->getEntity()->getId();

		$value = get_post_meta( $id, '_mpa_checkout_fields_' . $this->name, true );

		switch ( $this->type ) {

			case 'checkbox':
				if ( $value === '1' ) {
					$value = esc_html__( 'yes', 'mpa-checkout-fields' );
				} elseif ( $value === '0' ) {
					$value = esc_html__( 'no', 'mpa-checkout-fields' );
				} else {
					$value = '';
				}
				return $value;

				break;

			case 'country':
				$value = mpapp()->bundles()->countries()->getLabel( $value );
				return $value;

				break;

			case 'date_of_birth':
				$date = \DateTime::createFromFormat( 'Y-m-d', $value );
				if ( $date !== false ) {
					$value = date_i18n( mpapp()->settings()->getDateFormat(), $date->getTimestamp() );
				}
				return $value;

				break;

			case 'file_upload':

				if ( $value ) {
					$value = FileUploadField::getUploadedFileLink( $id, $this->name );
					return '<a href="' . esc_url( $value ) . '" target="_blank">' . esc_html__( 'View file', 'mpa-checkout-fields' ) . '</a>';
				} else {
					return '';
				}

				break;

			default:
				if ( $value ) {
					return $value;
				} else {
					return '';
				}

				break;
		}
	}
}