<?php

namespace MotoPress\Appointment\CheckoutFields\Fields;

use MotoPress\Appointment\Fields\AbstractField;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * @since 1.0
 */
class OptionsField extends AbstractField {

	/** @since 1.0 */
	const TYPE = 'options';

	/**
	 * @var array
	 *
	 * @since 1.0
	 */
	protected $default = array();

	/**
	 * @param mixed $value
	 * @return array
	 *
	 * @since 1.0
	 */
	protected function validateValue( $value ) {

		if ( '' === $value || ! is_array( $value ) ) {
			return $this->default;
		}

		$options = array();

		foreach ( $value as $option ) {
			if ( ! isset( $option['value'], $option['label'] ) ) {
				continue;
			}

			$value = sanitize_text_field( trim( $option['value'] ) );
			$label = sanitize_text_field( trim( $option['label'] ) );

			// Filter empty rows
			if ( '' !== $value || ! empty( $label ) ) {
				$options[] = compact( 'value', 'label' );
			}
		}

		return $options;
	}

	/**
	 * @return string
	 *
	 * @since 1.0
	 */
	public function renderInput() {

		$hasValues = ! empty( $this->value );

		// Add empty value in case of no rows
		$output = '<input type="hidden" name="' . esc_attr( $this->inputName ) . '" value="">';

		// Add form table
		$output .= '<table class="widefat striped mpa-table-centered' . ( $hasValues ? '' : ' mpa-hide' ) . '">';

			// Add table header
			$output         .= '<thead>';
				$output     .= '<tr>';
					$output .= '<th class="row-title column-value">' . esc_html__( 'Value', 'mpa-checkout-fields' ) . '</th>';
					$output .= '<th class="row-title column-label">' . esc_html__( 'Label', 'mpa-checkout-fields' ) . '</th>';
					$output .= '<th class="column-actions"></th>';
				$output     .= '</tr>';
			$output         .= '</thead>';

			// Add values
			$output .= '<tbody>';

		foreach ( $this->value as $option ) {
			$rowId      = uniqid();
			$namePrefix = "{$this->inputName}[{$rowId}]";

			$output         .= '<tr class="mpa-options-field-row" data-id="' . esc_attr( $rowId ) . '">';
				$output     .= '<td class="column-value">';
					$output .= '<input type="text" name="' . esc_attr( "{$namePrefix}[value]" ) . '" value="' . esc_attr( $option['value'] ) . '" class="large-text">';
				$output     .= '</td>';

				$output     .= '<td class="column-label">';
					$output .= '<input type="text" name="' . esc_attr( "{$namePrefix}[label]" ) . '" value="' . esc_attr( $option['label'] ) . '" class="large-text">';
				$output     .= '</td>';

				$output     .= '<td class="column-actions">';
					$output .= mpa_tmpl_dashicon( 'trash', 'mpa-remove-button' );
				$output     .= '</td>';
			$output         .= '</tr>';
		} // For each option

			$output .= '</tbody>';

		$output .= '</table>';

		// Add controls
		$output     .= '<p class="mpa-controls">';
			$output .= mpa_tmpl_button(
				esc_html__( 'Add New', 'mpa-checkout-fields' ),
				array(
					'class' => 'button button-secondary mpa-add-button',
				)
			);
		$output     .= '</p>';

		return $output;
	}
}
