<?php

use MotoPress\Appointment\CheckoutFields\Bundles\CustomerBundle;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * @return int
 *
 * @since 1.0.0
 */
function mpa_checkout_fields_get_editing_post_id() {
	$postId = 0;

	if ( is_admin() ) {
		if ( isset( $_REQUEST['post_ID'] ) && is_numeric( $_REQUEST['post_ID'] ) ) {
			$postId = intval( $_REQUEST['post_ID'] ); // On post update ($_POST)
		} elseif ( isset( $_REQUEST['post'] ) && is_numeric( $_REQUEST['post'] ) ) {
			$postId = intval( $_REQUEST['post'] ); // On post edit page ($_GET)
		}
	}

	return $postId;
}


/**
 * @param string $fieldName
 * @return bool
 *
 * @since 1.0.0
 */
function mpa_checkout_fields_is_default_customer_field( $fieldName ) {

	$isDefaultFields = new CustomerBundle();
	return $isDefaultFields->isDefaultField( $fieldName );
}

/**
 * @return array
 *
 * @since 1.0.0
 */
function mpa_checkout_fields_get_default_customer_fields() {

	$getDefaultFields = new CustomerBundle();
	return $getDefaultFields->getDefaultFields();
}

/**
 * @return array
 *
 * @since 1.0.0
 */

function mpa_checkout_fields_get_custom_customer_fields() {

	$getCustomCustomerFields = new CustomerBundle();
	return $getCustomCustomerFields->getCustomFields();
}

/**
 * @param int $month
 * @param int $year
 * @return int
 *
 * @since 1.0.0
 */
function mpa_checkout_fields_days_in_month( $month, $year ) {
	return cal_days_in_month( CAL_GREGORIAN, $month, $year );
}

/**
 * @param int|float $value
 * @param int|float $min
 * @param int|float $max
 * @return int|float
 *
 * @since 1.0.0
 */
function mpa_checkout_fields_limit( $value, $min, $max ) {
	return max( $min, min( $value, $max ) );
}

/**
 * Add an array after the specified position.
 *
 * @param array $array Subject array.
 * @param int   $position
 * @param array $insert Array to insert.
 * @return array Result array with inserted items.
 *
 * @since 1.0.0
 */
function mpa_checkout_fields_array_insert_after( $array, $position, $insert ) {
	if ( $position < 0 ) {
		return array_merge( $insert, $array );
	} elseif ( $position >= count( $array ) ) {
		return array_merge( $array, $insert );
	} else {
		return array_merge(
			array_slice( $array, 0, $position + 1, true ),
			$insert,
			array_slice( $array, $position + 1, count( $array ), true )
		);
	}
}

/**
 * @param array    $haystack
 * @param callable $checkCallback The callback check function. The function must
 *     return TRUE if the proper element was found or FALSE otherwise. Gets the
 *     value of the element as the first argument and the key as second.
 * @return mixed The key for searched element or FALSE.
 *
 * @since 1.0.0
 */
function mpa_checkout_fields_array_usearch( array $haystack, callable $checkCallback ) {
	foreach ( $haystack as $key => $value ) {
		if ( $checkCallback( $value, $key ) ) {
			return $key;
		}
	}

	return false;
}