<?php

namespace MotoPress\Appointment\CheckoutFields\Metaboxes;

use MotoPress\Appointment\Metaboxes\FieldsMetabox;
use MotoPress\Appointment\CheckoutFields\CheckoutFieldsHelper;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}


/**
 * @since 1.0
 */
class CheckoutFieldMetabox extends FieldsMetabox {

	/**
	 *
	 * @return string
	 */
	protected function theName(): string {
		return 'mpa_checkout_field_settings';
	}

	/**
	 *
	 * @return string
	 */
	public function getLabel(): string {
		return esc_html__( 'Checkout Field Parameters', 'mpa-checkout-fields' );
	}

	/**
	 * @return array
	 *
	 * @since 1.0
	 */
	protected function theFields() {

		$type_options = array(
			'checkbox'      => esc_html__( 'Checkbox', 'mpa-checkout-fields' ),
			'country'       => esc_html__( 'Country', 'mpa-checkout-fields' ),
			'date_of_birth' => esc_html__( 'Date of Birth', 'mpa-checkout-fields' ),
			'email'         => esc_html__( 'Email', 'mpa-checkout-fields' ),
			'heading'       => esc_html__( 'Heading', 'mpa-checkout-fields' ),
			'paragraph'     => esc_html__( 'Paragraph', 'mpa-checkout-fields' ),
			'phone'         => esc_html__( 'Phone', 'mpa-checkout-fields' ),
			'select'        => esc_html__( 'Select', 'mpa-checkout-fields' ),
			'text'          => esc_html__( 'Text', 'mpa-checkout-fields' ),
			'textarea'      => esc_html__( 'Textarea', 'mpa-checkout-fields' ),
			'file_upload'   => esc_html__( 'File Upload', 'mpa-checkout-fields' ),
		);

		$settingsFields = array(
			'mpa_cf_name'         => array(
				'type'        => 'text',
				'label'       => esc_html__( 'System Name', 'mpa-checkout-fields' ),
				'description' => esc_html__( 'Important: The plugin identifies this field using customer information. Only Latin lowercase letters, numbers, hyphens, and underscores are allowed. The name must be unique.', 'mpa-checkout-fields' ),
				'required'    => true,
				'pattern'     => '[a-z0-9_\-]+',
				'size'        => 'regular',
				'visibility'  => 'public',
			),
			'mpa_cf_type'         => array(
				'type'       => 'select',
				'label'      => esc_html__( 'Type', 'mpa-checkout-fields' ),
				'options'    => $type_options,
				'visibility' => 'public',
				'default'    => 'text',
			),
			'mpa_cf_inner_label'  => array(
				'type'       => 'text',
				'label'      => esc_html__( 'Checkbox Text', 'mpa-checkout-fields' ),
				'size'       => 'regular',
				'class'      => 'mpa-inner-label-ctrl',
				'visibility' => 'public',
			),
			'mpa_cf_text_content' => array(
				'type'        => 'rich-editor',
				'label'       => esc_html__( 'Text Content', 'mpa-checkout-fields' ),
				'size'        => 'wide',
				'rows'        => 4,
				'visibility'  => 'public',
				'class'       => 'mpa-text-content-ctrl',
				'editor_args' => array(
					'media_buttons' => false,
					'quicktags'     => array(
						'buttons' => 'strong,em,link',
					),
				),

			),
			'mpa_cf_placeholder'  => array(
				'type'        => 'text',
				'label'       => esc_html__( 'Placeholder', 'mpa-checkout-fields' ),
				'description' => esc_html__( 'Short hint that describes the expected value of this field.', 'mpa-checkout-fields' ),
				'size'        => 'regular',
				'class'       => 'mpa-placeholder-ctrl',
				'visibility'  => 'public',
			),
			'mpa_cf_pattern'      => array(
				'type'        => 'text',
				'label'       => esc_html__( 'Pattern', 'mpa-checkout-fields' ),
				// Translators: %s is a regular expression.
				'description' => sprintf( esc_html__( 'A regular expression that the input value must match to be valid. If using the pattern attribute, inform the user about the expected format. For example %s is a US phone number in the format of: 123-456-7890.', 'mpa-checkout-fields' ), '<code>\d{3}[\-]\d{3}[\-]\d{4}</code>' ),
				'size'        => 'regular',
				'class'       => 'mpa-pattern-ctrl',
				'visibility'  => 'public',
			),
			'mpa_cf_description'  => array(
				'type'        => 'rich-editor',
				'label'       => esc_html__( 'Description', 'mpa-checkout-fields' ),
				'description' => esc_html__( 'Any hint about this field that you want to display to your customers.', 'mpa-checkout-fields' ),
				'class'       => 'mpa-description-ctrl',
				'size'        => 'wide',
				'rows'        => 4,
				'visibility'  => 'public',
				'editor_args' => array(
					'media_buttons' => false,
					'quicktags'     => array(
						'buttons' => 'strong,em,link',
					),
				),
			),
			'mpa_cf_css_class'    => array(
				'type'        => 'text',
				'label'       => esc_html__( 'Additional CSS Class(es)', 'mpa-checkout-fields' ),
				'description' => esc_html__( 'Separate multiple classes with spaces.', 'mpa-checkout-fields' ),
				'size'        => 'regular',
				'visibility'  => 'public',
			),
			'mpa_cf_options'      => array(
				'type'        => 'options',
				'label'       => esc_html__( 'Options', 'mpa-checkout-fields' ),
				'description' => esc_html__( 'You can use the first option as a placeholder to guide users on what to enter; just leave the option value empty. Option Value is the system name for Visible Label, which users can see and you can edit anytime.', 'mpa-checkout-fields' ),
				'class'       => 'mpa-options-ctrl',
				'visibility'  => 'public',
				'size'        => 'regular',
			),
			'mpa_cf_file_types'   => array(
				'type'        => 'text',
				'label'       => esc_html__( 'File Types', 'mpa-checkout-fields' ),
				'class'       => 'mpa-file-types-ctrl',
				'description' => esc_html__( 'Allowed file extensions, separated by comma. For example: png, pdf, jpeg', 'mpa-checkout-fields' ),
				'size'        => 'regular',
				'visibility'  => 'public',
			),
			'mpa_cf_upload_size'  => array(
				'type'        => 'text',
				'label'       => esc_html__( 'Upload Size', 'mpa-checkout-fields' ),
				'class'       => 'mpa-upload-size-ctrl',
				'description' => esc_html__( 'Max upload file size in bytes. For example: 4000000', 'mpa-checkout-fields' ),
				'size'        => 'regular',
				'visibility'  => 'public',
			),
			'mpa_cf_checked'      => array(
				'name'       => 'checked',
				'type'       => 'checkbox',
				'label'      => '&nbsp;',
				'label2'     => esc_html__( 'Checked by default', 'mpa-checkout-fields' ),
				'class'      => 'mpa-checked-ctrl',
				'visibility' => 'public',
			),
			'mpa_cf_required'     => array(
				'type'        => 'checkbox',
				'label'       => '&nbsp;',
				'label2'      => esc_html__( 'Required', 'mpa-checkout-fields' ),
				'class'       => 'mpa-required-ctrl',
				'default'     => false,
				'description' => esc_html__( 'This field must be filled out before submitting the form.', 'mpa-checkout-fields' ),
				'visibility'  => 'public',
			),
			'mpa_cf_enabled'      => array(
				'type'        => 'checkbox',
				'label'       => '&nbsp;',
				'label2'      => esc_html__( 'Enabled', 'mpa-checkout-fields' ),
				'default'     => true,
				'description' => esc_html__( 'Display this field in the form.', 'mpa-checkout-fields' ),
				'visibility'  => 'public',
			),
		);

		$postId = mpa_checkout_fields_get_editing_post_id();

		if ( CheckoutFieldsHelper::isDefaultCheckoutFieldPost( $postId ) ) {

			$settingsFields['mpa_cf_name']['disabled']    = true;
			$settingsFields['mpa_cf_name']['description'] = esc_html__( 'You cannot change the name of this system field.', 'mpa-checkout-fields' );

			$settingsFields['mpa_cf_type']['disabled']    = true;
			$settingsFields['mpa_cf_type']['description'] = esc_html__( 'You cannot change the type of this system field.', 'mpa-checkout-fields' );

			$fieldName = get_post_meta( $postId, 'mpa_cf_name', true );
			if ( $fieldName === 'email' ) {
				$settingsFields['mpa_cf_required']['description'] = sprintf( '<strong>%s</strong>', esc_html__( 'Email field is crucial for customer account creation and email notifications. Make this field non-required only if the mentioned functionality is unnecessary.', 'mpa-checkout-fields' ) );
			}
		}

		// custom sidebar
		remove_meta_box( 'submitdiv', $this->postType, 'side' );
		add_meta_box( 'submitdiv', esc_html__( 'Update Checkout Field', 'mpa-checkout-fields' ), array( $this, 'displaySubmitMetabox' ), $this->postType, 'side' );

		return $settingsFields;
	}

	/**
	 * Show custom checkout field sidebar
	 *
	 * @param [type] $post
	 * @return void
	 */
	public function displaySubmitMetabox( $post ) {
		?>
		<div class="submitbox" id="submitpost">
			<div id="minor-publishing">
				<div id="misc-publishing-actions">
					<div class="misc-pub-section">
						<span><?php esc_html_e( 'Created on:', 'mpa-checkout-fields' ); ?></span>
						<strong><?php echo date_i18n( get_option( 'date_format' ) . ' @ ' . get_option( 'time_format' ), strtotime( $post->post_date ) ); ?></strong>
					</div>
				</div>
			</div>
			<div id="major-publishing-actions">
				<div id="delete-action">
					<?php
					if ( current_user_can( 'delete_post', $post->ID ) && ! CheckoutFieldsHelper::isDefaultCheckoutFieldPost( $post ) ) {
						if ( ! EMPTY_TRASH_DAYS ) {
							$deleteText = esc_html__( 'Delete Permanently', 'mpa-checkout-fields' );
						} else {
							$deleteText = esc_html__( 'Move to Trash', 'mpa-checkout-fields' );
						}
						?>
						<a class="submitdelete deletion" href="<?php echo get_delete_post_link( $post->ID ); ?>"><?php echo $deleteText; ?></a>
					<?php } ?>
				</div>
				<div id="publishing-action">
					<span class="spinner"></span>
					<input name="original_publish" type="hidden" id="original_publish" value="<?php esc_attr_e( 'Update', 'mpa-checkout-fields' ); ?>" />
					<input type="submit" name="publish" id="publish" class="button button-primary button-large" value="<?php in_array( $post->post_status, array( 'new', 'auto-draft' ) ) ? esc_attr_e( 'Create', 'mpa-checkout-fields' ) : esc_attr_e( 'Update', 'mpa-checkout-fields' ); ?>" />
				</div>
				<div class="clear"></div>
			</div>
		</div>
		<?php
	}

	/**
	 * Prevent changes in default appointment fields
	 *
	 * @param array    $values
	 * @param integer  $postId
	 * @param \WP_Post $post
	 * @return void
	 */
	protected function saveValues( array $values, int $postId, \WP_Post $post ) {

		// prevent update default fields
		if ( isset( $_POST['mpa_cf_name'] ) && ! CheckoutFieldsHelper::isDefaultCheckoutFieldPost( $postId ) ) {

			$name          = $_POST['mpa_cf_name'];
			$defaultFields = array_keys( mpa_checkout_fields_get_default_customer_fields() );

			if ( in_array( $name, $defaultFields ) ) {

				$suffix                          = '_' . $postId;
				$values['update']['mpa_cf_name'] = $name . $suffix;

				parent::saveValues( $values, $postId, $post );
			}
		}

		if ( CheckoutFieldsHelper::isDefaultCheckoutFieldPost( $postId ) ) {

			$fieldName = get_post_meta( $postId, 'mpa_cf_name', true );

			switch ( $fieldName ) {

				case 'name':
					$values['update']['mpa_cf_name'] = 'name';
					$values['update']['mpa_cf_type'] = 'text';
					break;

				case 'email':
					$values['update']['mpa_cf_name'] = 'email';
					$values['update']['mpa_cf_type'] = 'email';
					break;

				case 'phone':
					$values['update']['mpa_cf_name'] = 'phone';
					$values['update']['mpa_cf_type'] = 'phone';
					break;

			}
		}

		parent::saveValues( $values, $postId, $post );
	}
}
