<?php

namespace MotoPress\Appointment\CheckoutFields\Metaboxes;

use MotoPress\Appointment\CheckoutFields\Plugin;
use MotoPress\Appointment\Metaboxes\FieldsMetabox;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}


/**
 * @since 1.0
 */
class CheckoutFieldsBookingMetabox extends FieldsMetabox {

	/**
	 *
	 * @return string
	 */
	protected function theName(): string {
		return 'mpa_checkout_fields_booking_metabox';
	}

	/**
	 *
	 * @return string
	 */
	public function getLabel(): string {
		return esc_html__( 'Checkout Fields', 'mpa-checkout-fields' );
	}

	/**
	 * @return array
	 *
	 * @since 1.0
	 */
	public function theFields() {

		// Get custom fields
		$customFields = mpa_checkout_fields_get_custom_customer_fields();

		// add metabox props
		foreach ( $customFields as $fieldName => &$val ) {

			// if empty label show field name
			$val['label']    = $val['label'] === '' ? $fieldName : $val['label'];
			$val['required'] = false;

			switch ( $val['type'] ) {

				case 'text':
					$val['rows']    = 5;
					$val['default'] = '';
					$val['size']    = 'regular';
					break;

				case 'textarea':
					$val['rows']    = 5;
					$val['default'] = '';
					$val['size']    = 'large';
					break;

				case 'checkbox':
					$checkoutField = Plugin::getInstance()->getCheckoutFieldRepository()->findByMeta( 'mpa_cf_name', $fieldName );

					$val['size']    = 'regular';
					$val['label2']  = ! is_null( $checkoutField ) ? $checkoutField->innerLabel : '';
					$val['default'] = false;

					break;

				case 'select':
					$checkoutField = Plugin::getInstance()->getCheckoutFieldRepository()->findByMeta( 'mpa_cf_name', $fieldName );
					$fieldOptions  = $checkoutField->options;

					$val['rows']    = 5;
					$val['default'] = '';
					$val['size']    = 'regular';
					$val['options'] = $fieldOptions;

					break;

				case 'country':
					$checkoutField = Plugin::getInstance()->getCheckoutFieldRepository()->findByMeta( 'mpa_cf_name', $fieldName );
					$countries     = array( '' => esc_html__( '— Select —', 'mpa-checkout-fields' ) ) + mpapp()->bundles()->countries()->getCountries();

					$val['type']    = 'select';
					$val['rows']    = 5;
					$val['default'] = '';
					$val['size']    = 'regular';
					$val['options'] = $countries;

					break;

				case 'date_of_birth':
					$checkoutField = Plugin::getInstance()->getCheckoutFieldRepository()->findByMeta( 'mpa_cf_name', $fieldName );

					$val['type'] = 'date-of-birth';

					break;

				case 'file_upload':
					$checkoutField = Plugin::getInstance()->getCheckoutFieldRepository()->findByMeta( 'mpa_cf_name', $fieldName );
					$postId        = mpa_checkout_fields_get_editing_post_id();
					$link          = \MotoPress\Appointment\CheckoutFields\Fields\FileUploadField::getUploadedFileLink( $postId, $fieldName );
					$val['type']   = 'link-upload-button';

					if ( empty( $link ) ) {

						$val['name']   = $fieldName;
						$val['inner_class'] = 'disabled';
						$val['label2']  = esc_html__( 'File is not uploaded', 'mpa-checkout-fields' );

					} else {

						$val['name']   = $fieldName;
						$val['href']   = $link;
						$val['target'] = '_blank';
						$val['label2'] = esc_html__( 'View file', 'mpa-checkout-fields' );
					}

					break;

				default:
					$val['rows']    = 5;
					$val['default'] = '';
					$val['size']    = 'regular';

			}
		}

		// add prefix to checkout fields
		$mpa_cf_prefix = 'mpa_checkout_fields_'; // mpa_checkout_fields_somefield
		$customFields  = array_combine(
			array_map(
				function ( $keynames ) use ( $mpa_cf_prefix ) {
					return $mpa_cf_prefix . $keynames; },
				array_keys( $customFields )
			),
			$customFields
		);

		return $customFields;
	}
}
