<?php

namespace MotoPress\Appointment\CheckoutFields\PostTypes;

use MotoPress\Appointment\PostTypes\AbstractPostType;
use MotoPress\Appointment\CheckoutFields\CPTPages\ManageCheckoutFieldsPage;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}


/**
 * @since 1.0
 */
class CheckoutFieldPostType extends AbstractPostType {


	/** @since 1.0 */
	const POST_TYPE = 'mpa_checkout_field';

	/**
	 * @since 1.0
	 */
	protected function addActions() {
		parent::addActions();
	}

	/**
	 * @return string
	 *
	 * @since 1.0
	 */
	public function getLabel() {
		return esc_html__( 'Checkout Fields', 'mpa-checkout-fields' );
	}

	/**
	 * @return string
	 *
	 * @since 1.0
	 */
	public function getSingularLabel() {
		return esc_html__( 'Checkout Field', 'mpa-checkout-fields' );
	}

	/**
	 * @return string
	 *
	 * @since 1.0
	 */
	protected function getDescription() {
		return esc_html__( 'This is where you can add new checkout fields.', 'mpa-checkout-fields' );
	}

	/**
	 * @return array
	 *
	 * @since 1.0.0
	 */
	protected function getLabels() {
		return array(
			'name'                  => $this->getLabel(),
			'singular_name'         => $this->getSingularLabel(),
			'add_new'               => esc_html_x( 'Add New', 'Add New Checkout Field', 'mpa-checkout-fields' ),
			'add_new_item'          => esc_html__( 'Add New Checkout Field', 'mpa-checkout-fields' ),
			'new_item'              => esc_html__( 'New Checkout Field', 'mpa-checkout-fields' ),
			'edit_item'             => esc_html__( 'Edit Checkout Field', 'mpa-checkout-fields' ),
			'view_item'             => esc_html__( 'View Checkout Field', 'mpa-checkout-fields' ),
			'search_items'          => esc_html__( 'Search Checkout Fields', 'mpa-checkout-fields' ),
			'not_found'             => esc_html__( 'No checkout fields found', 'mpa-checkout-fields' ),
			'not_found_in_trash'    => esc_html__( 'No checkout fields found in Trash', 'mpa-checkout-fields' ),
			'all_items'             => esc_html__( 'Checkout Fields', 'mpa-checkout-fields' ),
		);
	}

	/**
	 * @return array
	 *
	 * @since 1.0.0
	 */
	protected function registerArgs() {
		return array(
			'public'       => false,
			'show_ui'      => true,
			'supports'     => array( 'title' ),
			'show_in_menu' => mpapp()->pages()->appointmentMenu()->getId(),
			'capabilities' => array(
				'create_posts' => 'create_' . static::POST_TYPE . 's',
			),
		);
	}

	public function createManagePage() {
		return new ManageCheckoutFieldsPage( static::POST_TYPE );
	}

}
