<?php

namespace MotoPress\Appointment\CheckoutFields\Repositories;

use MotoPress\Appointment\Repositories\AbstractRepository;
use MotoPress\Appointment\CheckoutFields\Entities\CheckoutField;

/**
 * @since 1.0
 */
class CheckoutFieldRepository extends AbstractRepository {

	/**
	 * @param \WP_Post|int $post
	 * @return \MotoPress\Appointment\CheckoutFields\Entities\CheckoutField
	 */
	public function mapPostToEntity( $post ) {
		if ( ! is_a( $post, '\WP_Post' ) ) {
			$post = get_post( $post );
		}

		$postId    = isset( $post->ID ) ? (int) $post->ID : null;
		$postTitle = isset( $post->post_title ) ? $post->post_title : '';

		$optionsValue = get_post_meta( $postId, 'mpa_cf_options', true );
		$options      = array();

		if ( is_array( $optionsValue ) ) {
			foreach ( $optionsValue as $optionsRow ) {
				$value = $optionsRow['value'];
				$label = $optionsRow['label'];

				$options[ $value ] = $label;
			}
		}

		$atts = array(
			'id'           => absint( $postId ),
			'title'        => $postTitle,
			'name'         => get_post_meta( $postId, 'mpa_cf_name', true ),
			'type'         => get_post_meta( $postId, 'mpa_cf_type', true ),
			'inner_label'  => get_post_meta( $postId, 'mpa_cf_inner_label', true ),
			'text_content' => get_post_meta( $postId, 'mpa_cf_text_content', true ),
			'placeholder'  => get_post_meta( $postId, 'mpa_cf_placeholder', true ),
			'pattern'      => get_post_meta( $postId, 'mpa_cf_pattern', true ),
			'description'  => get_post_meta( $postId, 'mpa_cf_description', true ),
			'css_class'    => get_post_meta( $postId, 'mpa_cf_css_class', true ),
			'options'      => $options,
			'file_types'   => get_post_meta( $postId, 'mpa_cf_file_types', true ),
			'upload_size'  => get_post_meta( $postId, 'mpa_cf_upload_size', true ),
			'checked'      => (bool) get_post_meta( $postId, 'mpa_cf_checked', true ),
			'enabled'      => (bool) get_post_meta( $postId, 'mpa_cf_enabled', true ),
			'required'     => (bool) get_post_meta( $postId, 'mpa_cf_required', true ),
		);
		return new CheckoutField( $atts );
	}

	/**
	 * @param \MotoPress\Appointment\CheckoutFields\Entities\CheckoutField $entity
	 */
	public function mapPostDataToEntity( $entity ) {

		$optionsSet = array();

		foreach ( $entity->options as $value => $label ) {
			$optionsSet[] = array(
				'value' => $value,
				'label' => $label,
			);
		}

		$fields = array(
			'ID'         => $entity->id,
			'post_title' => $entity->title,
			'postmeta'   => array(
				'mpa_cf_name'         => $entity->name,
				'mpa_cf_type'         => $entity->type,
				'mpa_cf_inner_label'  => $entity->innerLabel,
				'mpa_cf_text_content' => $entity->textContent,
				'mpa_cf_placeholder'  => $entity->placeholder,
				'mpa_cf_pattern'      => $entity->pattern,
				'mpa_cf_description'  => $entity->description,
				'mpa_cf_css_class'    => $entity->cssClass,
				'mpa_cf_options'      => $optionsSet,
				'mpa_cf_file_types'   => $entity->fileTypes,
				'mpa_cf_upload_size'  => $entity->uploadSize,
				'mpa_cf_checked'      => (int) $entity->isChecked,
				'mpa_cf_enabled'      => (int) $entity->isEnabled,
				'mpa_cf_required'     => (int) $entity->isRequired,
			),
		);

		return new CheckoutField( $fields );
	}

		/**
		 * @return array
		 */
	protected function entitySchema() {
		return array(
			'post'     => array( 'ID', 'post_title' ),
			'postmeta' => array(
				'_mpa_cf_name'         => true,
				'_mpa_cf_type'         => true,
				'_mpa_cf_inner_label'  => true,
				'_mpa_cf_text_content' => true,
				'_mpa_cf_placeholder'  => true,
				'_mpa_cf_pattern'      => true,
				'_mpa_cf_description'  => true,
				'_mpa_cf_css_class'    => true,
				'_mpa_cf_options'      => true,
				'_mpa_cf_file_types'   => true,
				'_mpa_cf_upload_size'  => true,
				'_mpa_cf_checked'      => true,
				'_mpa_cf_enabled'      => true,
				'_mpa_cf_required'     => true,
			),
		);
	}
}
