<?php
namespace MotoPress\Appointment\CheckoutFields\Views;

use MotoPress\Appointment\CheckoutFields\CheckoutFieldsHelper;
use MotoPress\Appointment\CheckoutFields\Fields\FileUploadField;
use MotoPress\Appointment\CheckoutFields\Fields\DateOfBirthField;

/**
 *
 * @since 1.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class RenderCheckoutField {

	/**
	 *
	 * @since 1.0
	 */
	public static function renderBeforeField( $field, $html_id ) {

		if ( $field->type != 'checkbox' ) {
			static::renderLabel( $field, $html_id );
			echo '<br />';
		}
	}

	/**
	 *
	 * @since 1.0
	 */
	public static function renderField( $field, $html_id ) {

		// Field classes
		$fieldClass = 'mpa-customer-';

		$inputId    = $inputName = $fieldClass . $field->name;
		$isRequired = CheckoutFieldsHelper::isFieldRequired( $field );

		$fileTypes  = $field->fileTypes;
		$uploadSize = $field->uploadSize;

		$atts = array(
			'name'  => $field->name,
			'id'    => $inputId . '-' . $html_id,
			'class' => $inputName,
			'type'  => $field->type,
		);

		if ( null !== $field->value ) {
			$atts['value'] = $field->value;
		}

		if ( $isRequired ) {
			$atts['required'] = 'required';
		}

		if ( ! empty( $field->placeholder ) ) {
			$atts['placeholder'] = $field->placeholder;
		}

		$output = '';

		switch ( $field->type ) {
			case 'text':
				if ( ! empty( $field->pattern ) ) {
					$atts['pattern'] = $field->pattern;
				}

				$output .= '<input' . mpa_tmpl_atts( $atts ) . ' />';

				break;

			case 'email':
				$output .= '<input' . mpa_tmpl_atts( $atts ) . ' />';

				break;

			case 'phone':
				$atts['type']         = 'tel';
				$atts['autocomplete'] = 'on';

				if ( ! empty( $field->pattern ) ) {
					$atts['pattern'] = $field->pattern;
				}

				$output .= '<input' . mpa_tmpl_atts( $atts ) . ' />';

				break;

			case 'textarea':
				$atts['rows'] = 4;

				$output .= '<textarea' . mpa_tmpl_atts( $atts ) . '></textarea>';

				break;

			case 'checkbox':
				$atts['value'] = '0';
				if ( $field->isChecked ) {
					$atts['checked'] = 'checked';
					$atts['value']   = '1';
				}

				$output .= '<input' . mpa_tmpl_atts( $atts ) . ' />';

				break;

			case 'select':
				$output .= mpa_tmpl_select( $field->options, '', $atts );

				break;

			case 'country':
				$countries      = array( '' => esc_html__( '— Select —', 'mpa-checkout-fields' ) ) + mpapp()->bundles()->countries()->getCountries();
				$defaultCountry = mpapp()->settings()->getCountry();

				$output .= mpa_tmpl_select( $countries, $defaultCountry, $atts );

				break;

			case 'date_of_birth':
				$atts['class'] .= ' mpa-dob-holder-control-component';
				$field          = new DateOfBirthField(
					$atts['name'],
					array(
						'required' => $isRequired,
						'htmlid'   => $html_id,
					)
				);

				$output  = '<input hidden name="' . esc_attr( $atts['name'] ) . '" id="' . esc_attr( $atts['id'] ) . '" class="' . esc_attr( $atts['class'] ) . '" type="' . esc_attr( $atts['type'] ) . '" />';
				$output .= $field->renderFields();

				break;

			case 'file_upload':
				$field = new FileUploadField(
					$atts['name'],
					array(
						'html_id'     => $html_id,
						'required'    => $isRequired,
						'file_types'  => $fileTypes,
						'upload_size' => $uploadSize,
					)
				);

				$output .= $field->renderFields();

				break;

		}

		echo $output;
	}

	/**
	 *
	 * @since 1.0
	 */
	public static function renderAfterField( $field, $html_id ) {

		if ( $field->type == 'checkbox' ) {
			static::renderLabel( $field, $html_id );
		}

		if ( ! empty( $field->description ) ) {
			echo '<span class="mpa-control-description">', wp_kses(
				$field->description,
				array(
					'a'      => array(
						'href'   => array(),
						'title'  => array(),
						'target' => array(),
					),
					'br'     => array(),
					'em'     => array(),
					'strong' => array(),
				)
			), '</span>';
		}
	}

	public static function renderLabel( $field, $html_id ) {

		// Field classes for default or custom fields
		$inputId = 'mpa-customer-' . $field->name . '-' . $html_id;

		$output = '<label for="' . esc_attr( $inputId ) . '">';

			$output .= $field->type != 'checkbox' ? esc_html( $field->title ) : esc_html( $field->innerLabel );

		if ( CheckoutFieldsHelper::isFieldRequired( $field ) ) {
			$output .= '&nbsp;';
			$output .= '<abbr title="' . esc_html__( 'Required', 'mpa-checkout-fields' ) . '">*</abbr>';
		}
		$output .= '</label>';

		echo $output;
	}
}
