<?php

namespace MotoPress\Appointment\CheckoutFields\Views;

use MotoPress\Appointment\CheckoutFields\Views\CheckoutFieldsView;
use MotoPress\Appointment\CheckoutFields\Plugin;
use MotoPress\Appointment\CheckoutFields\CheckoutFieldsHelper;

/**
 * @since 1.0
 */
class ViewActions {

	private $checkout_fields_view;

	public function __construct() {

		add_action( 'wp_enqueue_scripts', array( $this, 'enqueueCheckoutScripts' ) );

		$this->checkout_fields_view = new CheckoutFieldsView();

		add_action( 'init', array( $this, 'replaceCheckoutFields' ), 9 );
	}

	public function replaceCheckoutFields() {

		remove_action( 'appointment_form_checkout_form_fields', array( \MotoPress\Appointment\Views\ShortcodesView::getInstance(), 'appointmentFormCheckoutFields' ), 10 );
		add_action( 'appointment_form_checkout_form_fields', array( $this, 'appointmentFormCheckoutFields' ), 10 );
	}

	public function appointmentFormCheckoutFields( $args ) {
		$this->checkout_fields_view->renderEnabledFields( $args );
	}

	public function enqueueCheckoutScripts() {
		wp_enqueue_script(
			'mpa-cf-public',
			CheckoutFieldsHelper::getUrlToFile( 'assets/js/public.js' ),
			array( 'mpa-public', 'wp-hooks' ),
			Plugin::getInstance()->getPluginVersion(),
			true
		);

		wp_enqueue_script(
			'mpa-cf-date-of-birth',
			CheckoutFieldsHelper::getUrlToFile( 'assets/js/date-of-birth-control.js' ),
			array( 'jquery' ),
			Plugin::getInstance()->getPluginVersion(),
			true
		);

		wp_enqueue_style(
			'mpa-cf-checkout-styles',
			CheckoutFieldsHelper::getUrlToFile( 'assets/css/checkout-step.css' ),
			array(),
			Plugin::getInstance()->getPluginVersion()
		);

		wp_enqueue_script( 'uploadFile', CheckoutFieldsHelper::getUrlToFile( 'assets/js/file-uploads-control.js' ), array( 'jquery', 'wp-i18n' ), Plugin::getInstance()->getPluginVersion(), true );
		wp_localize_script( 'uploadFile', 'MPAFileUploadData', array( 
			'ajax_url' => admin_url( 'admin-ajax.php' ),
			'fileUploadNonce' => wp_create_nonce('mpa_cf_file_upload_nonce'),
		) );

	}
}
