<?php
namespace MotoPress\Appointment\Invoices;

use MotoPress\Appointment\Invoices\Number\InvoiceNumberHelper;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Adds actions and filters hooks of the plugin.
 */
class InvoicesHandler {

	public function __construct() {

		add_action( 'wp_enqueue_scripts', array( $this, 'enqueueInvoicesScripts' ) );

		// Add 'Invoice' button to 'Bookings' table
		add_filter( 'post_row_actions', 'mpa_invoice_add_print_button', 10, 2 );

		// Print PDFs
		add_action( 'admin_action_mpa-invoice', 'mpa_invoice_action_printpdf' );
		add_action( 'init', 'mpa_invoice_analyze_request', 999 );

		// Add the invoice number (ID) to new bookings
		add_action( 'mpa_booking_placed_by_user', array( InvoiceNumberHelper::class, 'addInvoiceIdToNewBooking' ), 10, 1 );

		// Print invoice link on booking step confirmation
		add_action( 'mpa_booking_details_section_after_end', 'mpa_invoice_pdf_link_to_confirmation' );

		// Print invoice link on customers page booking details payments section
		add_action( 'mpa_booking_details_payments_after_end', 'mpa_invoice_pdf_link_to_booking_details', 10, 1 );

		// admin settings tab styles
		add_action( 'admin_enqueue_scripts', array( $this, 'mpa_invices_enqueue_admin_style' ) );
	}

	function mpa_invices_enqueue_admin_style() {
		
		if ( mpapp()->pages()->settings()->isCurrentPage() ) {
			wp_register_style(
				'mpa-invoices-admin-css',
				$this::getUrlToFile( 'assets/css/settings-tab.css' ),
				array(),
				Plugin::getInstance()->getPluginVersion()
			);

			wp_enqueue_style( 'mpa-invoices-admin-css' );
		}
	}

	public function enqueueInvoicesScripts() {
		wp_enqueue_script(
			'mpa-invoices-public',
			$this::getUrlToFile( 'assets/js/public.js' ),
			array( 'mpa-public', 'wp-hooks' ),
			Plugin::getInstance()->getPluginVersion(),
			true
		);
	}

	/**
	 *
	 * @param string $fileRelativePath
	 * @return string
	 */
	public static function getUrlToFile( string $fileRelativePath ): string {

		return \MotoPress\Appointment\Invoices\PLUGIN_URL . $fileRelativePath;
	}
}
