<?php

namespace MotoPress\Appointment\Invoices;

use MotoPress\Appointment\Invoices\Admin\PluginLicenseSettingsField;

class Plugin {

	/** @var static */
	protected static $instance = null;

	/** @var \MotoPress\Appointment\Invoices\Emails\EmailInvoicesProcessor */
	protected $attachInvoices = null;

	/** @var \MotoPress\Appointment\Invoices\Admin\EddLicenseApi */
	private $eddLicenseApi = null;

	/** @var \MotoPress\Appointment\Invoices\Pdf\PdfHelper */
	protected $pdf = null;

	/** @var Dompdf */
	protected $dompdf;

	/** @var \MotoPress\Appointment\Invoices\Admin\InvoiceSettingsTab */
	protected $InvoiceSettingsTab = null;

	/** @var \MotoPress\Appointment\Invoices\Admin\PluginLifecycleHandler */
	private $pluginLifecycleHandler = null;

	// Prevent cloning of singleton
	public function __clone() {}
	public function __wakeup() {}

	public static function getInstance(): Plugin {

		if ( is_null( static::$instance ) ) {
			static::$instance = new static();
		}

		return static::$instance;
	}

	private function __construct() {

		$this->eddLicenseApi = new Admin\EddLicenseApi();

		load_plugin_textdomain(
			'mpa-invoices',
			false,
			plugin_basename( PLUGIN_DIR ) . 'languages/'
		);

		$this->pluginLifecycleHandler = new Admin\PluginLifecycleHandler( PLUGIN_FILE );

		add_action(
			'plugins_loaded',
			function () {
				$this->loadPlugin();
			}
		);

		$this->attachInvoices = new Emails\EmailInvoicesProcessor();
	}

	private function loadPlugin() {

		if ( ! $this->pluginLifecycleHandler->isWPEnvironmentSuitedForPlugin() ) {
			return;
		}

		// Register plugin custom settings field
		add_filter(
			'mpa_' . PluginLicenseSettingsField::TYPE . '_field_class',
			function () {
				return PluginLicenseSettingsField::class;
			}
		);

		PluginLicenseSettingsField::registerField();

		new InvoicesHandler();

		// Invoice metabox for booking
		new Metaboxes\InvoiceBookingMetabox( 'mpa_booking', 'side', 'low' );

		$this->pdf = new Pdf\PdfHelper();

		if ( ! wp_doing_ajax() ) {
			$this->InvoiceSettingsTab = new Admin\InvoiceSettingsTab();
		}
	}

	public function capabilities(): UsersAndRoles\Capabilities {
		return new UsersAndRoles\Capabilities();
	}

	/**
	 * @return \MotoPress\Appointment\Invoices\Pdf\PdfHelper
	 */
	public function pdf() {
		return $this->pdf;
	}

	public function getEddLicenseApi(): Admin\EddLicenseApi {
		return $this->eddLicenseApi;
	}

	public static function getPluginAuthorName(): string {
		return AUTHOR;
	}

	public static function getPluginVersion(): string {
		return VERSION;
	}

	public static function getPluginSourceServerUrl(): string {
		return STORE_URI;
	}

	public function isEDDLicenseEnabled(): bool {
		return (bool) apply_filters( 'mpa_invoices_use_edd_license', true );
	}
}
