<?php

namespace MotoPress\Appointment\Invoices\Admin;

use MotoPress\Appointment\Invoices\Plugin;
use MotoPress\Appointment\Invoices\Settings;
use MotoPress\Appointment\Invoices\Admin\EddLicenseApi;
use MotoPress\Appointment\Invoices\Number\InvoiceNumberTagsProcessor;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class InvoiceSettingsTab {

	const SETTINGS_TAB_SECTION_SLUG = 'mpa_invoices_settings';

	public function __construct() {

		// Add Invoices tab to appointment integration setings
		add_filter(
			'mpa_integrations_settings_tab_sections',
			function ( array $integrationsTabSections ) {

				$integrationsTabSections[ static::SETTINGS_TAB_SECTION_SLUG ] = __( 'Invoices', 'mpa-invoices' );

				return $integrationsTabSections;
			}
		);

		// Add fields to appointment integration setings tab
		add_filter(
			'mpa_integrations_section_settings',
			function ( array $settingsInvoices, string $currentSettingsTabSection ) {

				if ( static::SETTINGS_TAB_SECTION_SLUG === $currentSettingsTabSection ) {

					$settingsInvoices += $this->getSettingsInvoices();
				}

				return $settingsInvoices;
			},
			10,
			2
		);
	}

	// Settings fields to appointment integration setings tab
	private function getSettingsInvoices(): array {

		$attachmentOptions = array();
		$confirmationMode = get_option( 'mpa_confirmation_mode', 'auto' );

		switch ( $confirmationMode ) {

			case 'payment':
					$attachmentOptions = array(
						'admin_approved_booking_email'    => esc_html__( 'Admin: New Booking (Confirmation upon Payment)', 'mpa-invoices' ),
						'customer_approved_payment_email' => esc_html__( 'Customer: New Booking (Confirmation upon Payment)', 'mpa-invoices' ),
					);

				break;

			case 'manual':
					$attachmentOptions = array(
						'admin_pending_booking_email'     => esc_html__( 'Admin: New Booking Request (Confirmation by Admin)', 'mpa-invoices' ),
						'customer_pending_booking_email'  => esc_html__( 'Customer: Booking Request (Confirmation by Admin)', 'mpa-invoices' ),
						'customer_approved_booking_email' => esc_html__( 'Customer: Approved Booking Request (Confirmation by Admin)', 'mpa-invoices' ),
					);

				break;

			case 'auto':
					$attachmentOptions = array(
						'admin_new_booking_email'    => esc_html__( 'Admin: New Booking (Confirmed Automatically)', 'mpa-invoices' ),
						'customer_new_booking_email' => esc_html__( 'Customer: New Booking (Confirmed Automatically)', 'mpa-invoices' ),
					);

				break;
		}

		$settingsInvoices = array(
			'mpa_invoices_settings_group'          => array(
				'type'  => 'group',
				'label' => __( 'Invoices', 'mpa-invoicess' ),
			),
			"mpa_invoice_emails_attachment_{$confirmationMode}"        => array(
				'label'       => esc_html__( 'Attach Invoice to Email', 'mpa-invoices' ),
				'type'        => 'checklist',
				'options'     => $attachmentOptions,
				'description' => esc_html__( 'Select emails to send the invoice as an attachment. Alternatively, copy and paste the {pdf_invoice} tag into any other email or notification template to include the invoice.', 'mpa-invoices' ),
				'size'        => 'regular',
			),
			'mpa_invoice_title'                    => array(
				'type'        => 'text',
				'label'       => esc_html__( 'Invoice Title', 'mpa-invoices' ),
				'description' => '',
				'default'     => '',
				'size'        => 'regular',
			),
			'mpa_invoice_number_mask'              => array(
				'type'        => 'text',
				'label'       => esc_html__( 'Invoice Number Format', 'mpa-invoices' ),
				'description' => wp_kses( __( 'Select one or more tags from the available options or combine with text (e.g., ABC %YYYY%/%INVOICE_ID% &#8594; ABC 2024/0501)', 'mpa-invoices' ), array( 'code' => array() ) ) . InvoiceNumberTagsProcessor::getTagsDescription(),
				'default'     => Settings::DEFAULT_INVOICE_NUMBER_MASK,
				'size'        => 'regular',

			),
			'mpa_invoice_number_start'             => array(
				'type'        => 'text',
				'label'       => esc_html__( 'Starting Invoice ID', 'mpa-invoices' ),
				'description' => esc_html__( 'The starting number of the invoice ID. Add leading zeros to set the minimum invoice ID length.', 'mpa-invoices' ),
				'default'     => Settings::DEFAULT_INVOICE_START_NUMBER,
				'pattern'     => '\d+',
				'placeholder' => '0001',

			),
			'mpa_invoice_company_logo'             => array(
				'type'           => 'image',
				'label'          => esc_html__( 'Company Logo', 'mpa-invoices' ),
				'thumbnail_size' => 'full',
				'single'         => true,
				'description'    => '',
				'default'        => '',
			),
			'mpa_invoice_company_name'             => array(
				'type'        => 'text',
				'label'       => esc_html__( 'Company Name', 'mpa-invoices' ),
				'description' => esc_html__( 'Company name displayed on invoice.', 'mpa-invoices' ),
				'default'     => '',
			),
			'mpa_invoice_company_information'      => array(
				'type'        => 'textarea',
				'label'       => esc_html__( 'Company Information', 'mpa-invoices' ),
				'description' => esc_html__( 'Company information displayed on invoice.', 'mpa-invoices' ),
				'default'     => '',
				'size'        => 'large',
				'rows'        => 5,
			),
			'mpa_invoice_bottom_information'       => array(
				'type'        => 'textarea',
				'label'       => esc_html__( 'Additional Information', 'mpa-invoices' ),
				'description' => esc_html__( 'This text will appear at the bottom of the invoice.', 'mpa-invoices' ),
				'default'     => '',
				'size'        => 'large',
				'rows'        => 5,
			),
			'mpa_invoice_add_link_to_confirmation' => array(
				'type'    => 'checkbox',
				'label'   => esc_html__( 'Invoice Link on Confirmation Page', 'mpa-invoices' ),
				'label2'  => esc_html__( 'Add a link to a PDF invoice to the booking confirmation page on your site.', 'mpa-invoices' ),
				'default' => false,
			),
			'mpa_invoice_choose_font'              => array(
				'type'        => 'select',
				'options'     => array(
					'open_sans'       => esc_html__( 'Open Sans', 'mpa-invoice' ),
					'courier'         => esc_html__( 'Courier', 'mpa-invoice' ),
					'dejavu'          => esc_html__( 'DejaVu', 'mpa-invoice' ),
					'helvetica'       => esc_html__( 'Helvetica', 'mpa-invoice' ),
					'ipam'            => esc_html__( 'Ipam (Japanese)', 'mpa-invoice' ),
					'times'           => esc_html__( 'Times', 'mpa-invoice' ),
					'ibmplexsansthai' => esc_html__( 'IBM Plex Sans (Thai)', 'mpa-invoice' ),
				),

				'label'       => esc_html__( 'Font', 'mpa-invoice' ),
				'description' => esc_html__( 'Font that will be used for the PDF template.', 'mpa-invoice' ),
			),
		);

		if ( Plugin::getInstance()->isEDDLicenseEnabled() ) {
			$settingsInvoices[ EddLicenseApi::OPTION_KEY ] = array(
				'type'         => 'invoices-license-settings',
				'label'        => __( 'License Key', 'mpa-invoicess' ),
				'description'  => __( "<i>The License Key is required in order to get automatic plugin updates and support. You can manage your License Key in your personal account. <a href='https://motopress.zendesk.com/hc/en-us/articles/202812996-How-to-use-your-personal-MotoPress-account' target='blank'>Learn more</a>.</i>", 'mpa-invoicess' ),
				'size'         => 'regular',
				'translatable' => false,

			);
		}

		return $settingsInvoices;
	}
}
