<?php

namespace MotoPress\Appointment\Invoices\Emails;

use MotoPress\Appointment\Invoices\Emails\BookingInvoicesTags;

class EmailInvoicesProcessor {

	private $email;
	private $booking;
	private $attachments;
	const INVOICE_TAG = 'pdf_invoice';

	public function __construct() {

		// email tag
		add_filter( 'mpa_admin_approved_booking_email_tags', array( $this, 'addInvoiceTag' ), 10, 1 );
		add_filter( 'mpa_admin_new_booking_email_tags', array( $this, 'addInvoiceTag' ), 10, 1 );
		add_filter( 'mpa_admin_pending_booking_email_tags', array( $this, 'addInvoiceTag' ), 10, 1 );
		add_filter( 'mpa_customer_approved_payment_email_tags', array( $this, 'addInvoiceTag' ), 10, 1 );
		add_filter( 'mpa_customer_new_booking_email_tags', array( $this, 'addInvoiceTag' ), 10, 1 );
		add_filter( 'mpa_customer_cancelled_booking_email_tags', array( $this, 'addInvoiceTag' ), 10, 1 );
		add_filter( 'mpa_customer_pending_booking_email_tags', array( $this, 'addInvoiceTag' ), 10, 1 );
		add_filter( 'mpa_customer_approved_booking_email_tags', array( $this, 'addInvoiceTag' ), 10, 1 );
		add_filter( 'mpa_customer_cancelled_booking_email_tags', array( $this, 'addInvoiceTag' ), 10, 1 );
		// notification tag
		add_filter( 'mpa_notification_email_tags', array( $this, 'addInvoiceTag' ), 10, 1 );

		// replace tag
		add_filter( 'mpa_email_pre_replace_tag_content', array( $this, 'replaceTags' ) );
		add_filter( 'mpa_notification_pre_replace_tag_content', array( $this, 'replaceTags' ) );
		add_filter( 'mpa_sms_pre_replace_tag_content', array( $this, 'smsClearInvoiceTag' ) );

		// email data
		add_action( 'mpa_before_send_email', array( $this, 'captureEmailData' ), 10, 2 );
	}

	/**
	 * Add invoices tag
	 *
	 * @param [type] $tags
	 */
	public function addInvoiceTag( $tags ) {
		$invocesTag = $tags->getTags();
		$invocesTag['booking']->add( new BookingInvoicesTags( self::INVOICE_TAG, __( 'PDF Invoice', 'mpa-invoices' ) ) );
		return $tags;
	}

	/**
	 * Getting email data
	 *
	 * @param [type] $email
	 * @param [type] $booking
	 */
	public function captureEmailData( $email, $booking ) {
		$this->booking = $booking;
		$this->email   = $email;
	}

	/**
	 * Clear invoice tag on sms
	 *
	 * @param string $message
	 * @return string
	 */
	public function smsClearInvoiceTag( string $message ): string {
		$invoiceTag = '{' . self::INVOICE_TAG . '}';

		if ( stripos( $message, $invoiceTag ) !== false ) {
			$message = str_ireplace( $invoiceTag, '', $message );
		}
		return $message;
	}

	/**
	 *
	 * @param string $emailContent
	 * @return string
	 */
	public function replaceTags( string $emailContent ): string {

		if ( strpos( $emailContent, '{' . self::INVOICE_TAG . '}' ) !== false ) {
			if ( has_filter( 'wp_mail', array( $this, 'beforeMail' ) ) === false ) {
				add_filter( 'wp_mail', array( $this, 'beforeMail' ) );
			}
		} else {

			if ( is_null( $this->email ) ) {
				return $emailContent;
			}

			$confirmationMode       = get_option( 'mpa_confirmation_mode', 'auto' );
			$optionEmailsAttachment = get_option( "mpa_invoice_emails_attachment_{$confirmationMode}", array() );
			$emailName              = $this->email->getName();

			if ( in_array( $emailName, $optionEmailsAttachment ) ) {
				if ( has_filter( 'wp_mail', array( $this, 'beforeMail' ) ) === false ) {
					add_filter( 'wp_mail', array( $this, 'beforeMail' ) );
				}
			}
		}
		return $emailContent;
	}

	/**
	 * Generate and add attachment file
	 *
	 * @param [type] $args
	 */
	public function beforeMail( $args ) {
		remove_filter( 'wp_mail', array( $this, 'beforeMail' ) );

		if ( is_null( $this->booking ) ) {
			return $args;
		}

		$args['attachments'] = mpainvoice()->pdf()->addInvoicePdfAttachment( $args['attachments'], $this->booking );
		$this->attachments   = $args['attachments'];

		add_action( 'mpa_after_send_email', array( $this, 'afterMailCleanup' ) );

		return $args;
	}

	/**
	 * Remove invoice file after sending mail
	 *
	 * @return void
	 */
	public function afterMailCleanup() {
		remove_action( 'mpa_after_send_email', array( $this, 'afterMailCleanup' ) );

		foreach ( $this->attachments as $filepath ) {
			if ( strpos( $filepath, 'invoice-' ) > -1 && strpos( $filepath, '.pdf' ) > -1 && file_exists( $filepath ) ) {
				unlink( $filepath );
			}
		}
	}
}
