<?php

use MotoPress\Appointment\Invoices\UsersAndRoles\Capabilities;

/**
 * @return \MotoPress\Appointment\Invoices\Plugin
 */
function mpainvoice() {
	return \MotoPress\Appointment\Invoices\Plugin::getInstance();
}

/**
 * @return int
 */
function mpa_invoices_get_editing_booking() {
	$postId = 0;

	if ( is_admin() ) {
		if ( isset( $_REQUEST['post_ID'] ) && is_numeric( $_REQUEST['post_ID'] ) ) {
			$postId = intval( $_REQUEST['post_ID'] ); // On post update ($_POST)
		} elseif ( isset( $_REQUEST['post'] ) && is_numeric( $_REQUEST['post'] ) ) {
			$postId = intval( $_REQUEST['post'] ); // On post edit page ($_GET)
		}

		return ( $postId > 0 ) ? mpapp()->repositories()->booking()->findById( $postId ) : null;
	}
}

/**
 * Add 'Invoice' button to 'Bookings' table
 *
 * @return array $actions
 */
function mpa_invoice_add_print_button( $actions, $post ) {

	global $current_screen;

	if ( $current_screen->id !== 'edit-mpa_booking' ) {
		return $actions;
	}

	if ( ! current_user_can( Capabilities::GENERATE_INVOICES ) ) {
		return $actions;
	}

	$nonce        = wp_create_nonce( 'mpa-invoice' );
	$invoice_link = admin_url( 'admin.php?post=' . $post->ID . '&action=mpa-invoice&_wpnonce=' . $nonce );

	$actions['mpa-invoice'] = '<a target="_blank" href="' . $invoice_link
		. '" title="'
		. esc_attr( __( 'Open invoice in PDF', 'mpa-invoices' ) )
		. '">' . __( 'Invoice', 'mpa-invoices' ) . '</a>';

	return $actions;
}


/**
 * Print PDF action
 *
 * @return void
 */
function mpa_invoice_action_printpdf() {

	if (
		( isset( $_GET['action'] ) && 'mpa-invoice' == $_GET['action'] )
		&& ! isset( $_GET['post'] )
	) {
		wp_die( esc_html__( 'No booking found!', 'mpa-invoices' ) );
	}

	if ( ! empty( $_GET['_wpnonce'] ) &&
		wp_verify_nonce( sanitize_text_field( wp_unslash( $_GET['_wpnonce'] ) ), 'mpa-invoice' ) &&
		current_user_can( Capabilities::GENERATE_INVOICES )
	) {
		$id = (int) $_GET['post'];

		if ( $id ) {
			mpainvoice()->pdf()->printPdf( $id );
			exit;

		} else {
			wp_die( esc_html__( 'No booking found!', 'mpa-invoices' ) );
		}
	} else {
		wp_die( esc_html__( 'You don\'t have permission for this action.', 'mpa-invoices' ) );
	}
}

/**
 * Generate HTML for invoice link
 *
 * @return string
 */
function mpa_generate_invoice_html( $booking_id ) {
	$html = '<div class="mpa-booking-details-section-row">';
	$html .= '<span class="cell label">Invoice:</span>';
	$html .= '<div class="cell value">';
	$html .= '<a class="invoice-link" target="_blank" href="' .
		esc_url(
			add_query_arg(
				array(
					'action'         => 'mpa-print-invoice',
					'mpa_booking_id' => $booking_id,
				)
			)
		)
		. '">' .
		__( 'View Invoice', 'mpa-invoices' ) . '</a>';
	$html .= '</div></div>';

	return $html;
}

/**
 * Add invoice link to appointment step booking confirmation
 *
 * @return void
 */
function mpa_invoice_pdf_link_to_confirmation() {

	$add_link = get_option( 'mpa_invoice_add_link_to_confirmation', false );

	if ( $add_link ) {
		$html  = '<div class="mpa-booking-details-section booking-invoice">';
		$html .= '<div class="mpa-booking-details-section-row">';
		$html .= '<span class="cell label">Invoice:</span>';
		$html .= '<div class="cell value">';
		$html .= '<a class="invoice-link" target="_blank" href="' .
			esc_url(
				add_query_arg(
					array(
						'action' => 'mpa-print-invoice',
					)
				)
			)
			. '">' .
			__( 'View Invoice', 'mpa-invoices' ) . '</a>';
		$html .= '</div></div></div>';

		echo wp_kses_post( $html );
	}
}

/**
 * Add invoice link to appointment booking details on user account page
 *
 * @return void
 */
function mpa_invoice_pdf_link_to_booking_details( $booking ) {
	$booking_id = $booking->getID();
	echo wp_kses_post( '<div class="mpa-booking-details-section booking-invoice">' . mpa_generate_invoice_html( $booking_id ) . '</div>' );
}

function mpa_invoice_analyze_request() {

	if ( isset( $_GET['action'] ) &&
		sanitize_text_field( wp_unslash( $_GET['action'] ) ) === 'mpa-print-invoice' ) {

		$booking_id = isset( $_GET['mpa_booking_id'] ) ? sanitize_text_field( wp_unslash( $_GET['mpa_booking_id'] ) ) : false;

		if ( $booking_id ) {

			$booking = mpapp()->repositories()->booking()->findById( $booking_id );

			if ( $booking ) {

				mpainvoice()->pdf()->printPdf( $booking_id );
				die();

			} else {
				die( esc_html__( 'No booking found!', 'mpa-invoices' ) );
			}
		} else {
			die( esc_html__( 'No booking found!', 'mpa-invoices' ) );
		}
	}
}
