<?php

namespace MotoPress\Appointment\Invoices\Number;

use MotoPress\Appointment\Entities\Booking;
use MotoPress\Appointment\Invoices\Settings;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class InvoiceNumberHelper {

	const INVOICE_ID_META = '_mpa_invoice_id';

	/**
	 * See includes/InvoicesHandler.php.
	 */
	public static function addInvoiceIdToNewBooking( Booking $booking ): void {
		$invoiceId = static::getNextBookingInvoiceId();

		add_post_meta( $booking->getId(), static::INVOICE_ID_META, $invoiceId, true );
	}

	public static function getBookingInvoiceId( int $bookingId ): int {
		$invoiceNumber = get_post_meta( $bookingId, static::INVOICE_ID_META, true );

		if ( $invoiceNumber !== '' ) {
			$invoiceNumber = absint( $invoiceNumber );
		} else {
			$invoiceNumber = $bookingId;
		}

		return $invoiceNumber;
	}

	public static function getBookingInvoiceIdPadded( int $bookingId ): string {
		$invoiceNumber = static::getBookingInvoiceId( $bookingId );
		$minLength     = Settings::getInvoiceNumberMinLength();

		return str_pad( (string) $invoiceNumber, $minLength, '0', STR_PAD_LEFT );
	}

	/**
	 * @global \wpdb $wpdb
	 */
	public static function getNextBookingInvoiceId(): int {
		global $wpdb;

		$startNumber = absint( Settings::getInvoiceStartNumber() );

		$lastNumber = $wpdb->get_var(
			'SELECT MAX(CAST(`meta_value` AS UNSIGNED))'
			. " FROM `{$wpdb->postmeta}`"
			. " WHERE `meta_key` = '" . static::INVOICE_ID_META . "'"
		);
		$lastNumber = ! is_null( $lastNumber ) ? absint( $lastNumber ) : 0;

		$nextNumber = max( $startNumber, $lastNumber + 1 );

		return $nextNumber;
	}
}
