<?php

namespace MotoPress\Appointment\Invoices\UsersAndRoles;

use MotoPress\Appointment\Invoices\Plugin;
use MotoPress\Appointment\Handlers\SecurityHandler;

/**
 * @since 1.0.0
 */
class Capabilities {

	const GENERATE_INVOICES = 'mpa_invoices_generate';

	/**
	 * @var string
	 */
	public $capabilities;

	/**
	 * @var string
	 */
	public $roles;

	public function __construct() {

		$this->mapCapabilitiesToRoles();
		$this->mapRolesToCapabilities();
	}

	public static function setup() {

		global $wp_roles;

		if ( ! class_exists( 'WP_Roles' ) ) {
			return;
		}

		if ( ! isset( $wp_roles ) ) {
			$wp_roles = new \WP_Roles();
		}

		$customRoles = Plugin::getInstance()->capabilities()->getRoles();

		if ( ! empty( $customRoles ) ) {
			foreach ( $customRoles as $role => $capabilities ) {
				if ( ! empty( $capabilities ) ) {
					foreach ( $capabilities as $cap ) {
						$wp_roles->add_cap( $role, $cap );
					}
				}
			}
		}
	}

	public function mapCapabilitiesToRoles() {

		$this->capabilities[ self::GENERATE_INVOICES ] = array(
			'administrator',
		);

		if (
			class_exists( '\MotoPress\Appointment\Handlers\SecurityHandler' ) &&
			defined( '\MotoPress\Appointment\Handlers\SecurityHandler::ROLE_APPOINTMENT_MANAGER' )
		) {
			array_push( $this->capabilities[ self::GENERATE_INVOICES ], SecurityHandler::ROLE_APPOINTMENT_MANAGER );
		}
	}

	public function mapRolesToCapabilities() {

		if ( ! empty( $this->capabilities ) ) {

			foreach ( $this->capabilities as $capability => $roles ) {

				array_map(
					function ( $role ) use ( $capability ) {
						if ( ! isset( $this->roles[ $role ] ) ) {
							$this->roles[ $role ] = array();
						}
						if ( ! in_array( $capability, $this->roles[ $role ] ) ) {
							array_push( $this->roles[ $role ], $capability );
						}
					},
					$roles
				);
			}
		}
	}

	/**
	 * @return array
	 */
	public function getCapabilities() {
		return $this->capabilities;
	}

	/**
	 * @return array
	 */
	public function getRoles() {
		return $this->roles;
	}
}
