<?php

namespace MotoPress\Appointment\Addons\TwilioSMS;

use MotoPress\Appointment\Handlers\AbstractSMSNotificationSender;
use \MotoPress\Appointment\Helpers\AdminUIHelper;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}


class TwilioSMSNotificationSender extends AbstractSMSNotificationSender {

	private $twilioClient;

	public function __construct() {

		parent::__construct();

		try {

			$this->twilioClient = new \Twilio\Rest\Client(
				MPATwilioSMS::getTwilioAccountSID(),
				MPATwilioSMS::getTwilioAuthToken()
			);

		} catch ( \Throwable $e ) {

			$this->twilioClient = null;
		}
	}

	public static function getSenderId(): string {
		return 'mpa_twilio_sms_notification_sender';
	}

	public static function getSenderName(): string {
		return __( 'Twilio SMS Notification Sender', 'mpa-twilio-sms' );
	}

	public function getSettingsFields(): array {

		$settingsFields = array(
			'twilio_sms_sender_group'                      => array(
				'type'  => 'group',
				'label' => esc_html__( 'Twilio', 'mpa-twilio-sms' ),
			),
			MPATwilioSMS::SETTINGS_NAME_TWILIO_ACCOUNT_SID => array(
				'type'         => 'text',
				'label'        => __( 'Account SID', 'mpa-twilio-sms' ),
				'description'  => sprintf(
					// translators: %s is link to Twilio account
					__( 'Your Account SID from %s', 'mpa-twilio-sms' ),
					'<a href="https://console.twilio.com">https://console.twilio.com</a>'
				),
				'value'        => MPATwilioSMS::getTwilioAccountSID(),
				'size'         => 'regular',
				'translatable' => false,
			),
			MPATwilioSMS::SETTINGS_NAME_TWILIO_AUTH_TOKEN  => array(
				'type'         => 'text',
				'label'        => __( 'Auth Token', 'mpa-twilio-sms' ),
				'description'  => sprintf(
					// translators: %s is link to Twilio account
					__( 'Your Auth Token from %s', 'mpa-twilio-sms' ),
					'<a href="https://console.twilio.com">https://console.twilio.com</a>'
				),
				'value'        => MPATwilioSMS::getTwilioAuthToken(),
				'size'         => 'regular',
				'translatable' => false,
			),
			MPATwilioSMS::SETTINGS_NAME_TWILIO_FROM_CONTACT => array(
				'type'         => 'text',
				'label'        => __( 'From Contact', 'mpa-twilio-sms' ),
				'description'  => sprintf(
					// translators: %s is link to Twilio account
					__( 'Twilio phone number, shortcode or Messaging Service SID. You can get it in %s. Note that you cannot spoof messages from your personal cell phone number without porting your number to Twilio first.', 'mpa-twilio-sms' ),
					'<a href="https://console.twilio.com">https://console.twilio.com</a>'
				),
				'value'        => MPATwilioSMS::getTwilioFromContact(),
				'size'         => 'regular',
				'translatable' => false,
			),
		);

		if ( MPATwilioSMS::isEDDLicenseEnabled() ) {

			$settingsFields[ MPATwilioSMS::SETTINGS_NAME_PLUGIN_LICENSE_KEY ] = array(
				'type'        => PluginLicenseSettingsField::TYPE,
				'label'       => __( 'License Key', 'mpa-twilio-sms' ),
				'description' => __( "The License Key is required in order to get automatic plugin updates and support. You can manage your License Key in your personal account. <a href='https://motopress.zendesk.com/hc/en-us/articles/202812996-How-to-use-your-personal-MotoPress-account' target='blank'>Learn more</a>.", 'mpa-twilio-sms' ),
				'size'        => 'regular',
			);
		}

		return $settingsFields;
	}

	/**
	 * @throws \Exception if sms was not send
	 */
	protected function sendSMS( string $phoneNumber, string $message ) {

		if ( null === $this->twilioClient ) {

			throw new \Exception( 'Twilio settings are not set correctly' );
		}

		$response = $this->twilioClient->messages->create(
			$phoneNumber,
			array(
				'body' => $message,
				'from' => MPATwilioSMS::getTwilioFromContact(),
			)
		);

		if ( ! empty( $response->errorMessage ) ) {

			throw new \Exception(
				'Could not send SMS to ' . $phoneNumber . ' because of: ' . $response->errorMessage
			);
		}
	}
}
