

class WooCommerceGateway
{
    /**
     * @param {Object} $mountWrapper
     * @param {Cart} cart
     */
    constructor( $mountWrapper, cart )
    {
        /**
		 * @var {String}
		 */
		this.gatewayId = 'woocommerce';

		/**
		 * @var {Object}
		 */
		this.$mountWrapper = $mountWrapper;

		/**
		 * @var {Promise}
		 */
		this.loadPromise = null;

		/**
		 * @var {Boolean}
		 */
		this.isEnabled = false;

		/**
		 * @var {Boolean}
		 */
		this.isMounted = false;

		/**
		 * @var {Boolean}
		 */
		this.haveErrors = false;

        /**
		 * @var {Cart}
		 */
        this.cart = cart;

        this.$gatewayPreloader = $mountWrapper.parent().find('.mpa-payment-gateway-title .mpa-preloader');
    }

    /**
	 * @return {Promise}
	 */
	load()
	{
		this.loadPromise = Promise.resolve(this);

		return this.loadPromise;
	}

    onCartChange( cart ) {}

    /**
     * @return {Promise}
     */
    ready()
    {
        return this.loadPromise;
    }

    enable()
    {
        if ( !this.isEnabled ) {

            if ( !this.isMounted ) {

                this.isMounted = true;
            }

            this.$mountWrapper.removeClass('mpa-hide');
            this.isEnabled = true;
        }
    }

    disable()
    {
        if ( this.isEnabled ) {

            this.$mountWrapper.addClass('mpa-hide');
            this.isEnabled = false;
        }
    }

    /**
     * @return {Boolean}
     */
    isValid()
    {
        return !this.haveErrors;
    }

	reset() {}

    /**
     * @param {Cart} cart
	 * @param {Object} bookingDetails Booking and payment ID/UID.
	 * @return {Promise}
	 */
	processPayment( cart, bookingDetails )
    {
        if ('undefined' === typeof wc_add_to_cart_params) return false;

        this.$gatewayPreloader.removeClass('mpa-hide');

        jQuery.when(
            wp.apiRequest({
                path: '/motopress/appointment/v1/payments/prepare',
                type: 'POST',
                data: {
                    payment_details: cart.paymentDetails,
                }
            }),

            jQuery.ajax(
                {
                    url: wc_add_to_cart_params.wc_ajax_url.toString().replace('%%endpoint%%', 'add_to_cart'),
                    type: 'POST',
                    data: {
                        product_id: mpawooScriptData.wooProductId,
                        quantity: 1,
                        mpa_booking_id: cart.paymentDetails['booking_id'],
                        mpa_coupon_code: cart.paymentDetails['coupon_code'],
                        mpa_deposit: cart.paymentDetails['deposit']
                    },
                }
            )
        )
        .done((preparePaymentResponse, addToCartResponse) => {
            this.$gatewayPreloader.addClass('mpa-hide');
            if ( addToCartResponse ){
                window.location = mpawooScriptData.wooCheckoutUrl;
            }
        })
        .fail( (jqXHR, textStatus) => {
            this.$gatewayPreloader.addClass('mpa-hide');
            throw new Error();
        });

        return false;
    }
}

wp.hooks.addFilter( 
    'mpa_create_gateway',
    'MotoPress\Appointment\Addons\WooCommerce',
    (gateway, gatewayId, $billingFields, cart) => {

        if ( !gateway && 'woocommerce' === gatewayId ) {

            gateway = new WooCommerceGateway( $billingFields, cart );
        }

        return gateway;
    },
    10
);
